﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace AircraftBrowser
{
    public partial class AddAircraftDialog : Form
    {
        public Aircraft Aircraft { get; private set; }

        public AddAircraftDialog()
        {
            InitializeComponent();
        }

        private void okButton_Click(object sender, EventArgs e)
        {
            if (ValidateChildren())
            {
                Aircraft = new Aircraft(modelBox.Text, tailNumberBox.Text, colourButton.BackColor);

                DialogResult = DialogResult.OK;
                Close();
            }
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }

        private void modelBox_Validating(object sender, CancelEventArgs e)
        {
            if (!modelBox.Items.Contains(modelBox.Text))
            {
                errorProvider.SetError(modelBox, "Unrecognized model.");
                e.Cancel = true;
            }
            else
            {
                errorProvider.SetError(modelBox, null);
            }
        }

        private void tailNumberBox_Validating(object sender, CancelEventArgs e)
        {
            if (tailNumberBox.Text.Length < 4)
            {
                errorProvider.SetError(tailNumberBox, "Tail number must be at least 4 characters long.");
                e.Cancel = true;
            }
            else if (tailNumberBox.Text.Length > 8)
            {
                errorProvider.SetError(tailNumberBox, "Tail number cannot be longer than 8 characters.");
                e.Cancel = true;
            }
            else
            {
                errorProvider.SetError(tailNumberBox, null);
            }
        }

        private void colourButton_Click(object sender, EventArgs e)
        {
            ColorDialog diag = new ColorDialog();

            diag.Color = colourButton.BackColor;

            if (diag.ShowDialog() == DialogResult.OK)
            {
                colourButton.BackColor = diag.Color;
            }
        }
    }
}
