﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace AircraftBrowser
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        #region ToolStripMenuClicks

        private void addToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AddAircraftDialog diag = new AddAircraftDialog();

            if (diag.ShowDialog() == DialogResult.OK)
            {
                aircraftBox.Items.Add(diag.Aircraft);
            }
        }

        private void quitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void saveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SaveFileDialog diag = new SaveFileDialog();

            diag.AddExtension = true;
            diag.DefaultExt = "adb";

            if (diag.ShowDialog() == DialogResult.OK)
            {
                using (StreamWriter sw = new StreamWriter(diag.FileName))
                {
                    foreach (object item in aircraftBox.Items)
                    {
                        Aircraft aircraft = item as Aircraft;

                        sw.WriteLine("{0};{1};{2}", aircraft.Model,
                            aircraft.TailNumber, aircraft.Colour.Name);
                    }
                }
            }
        }

        private void loadToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenFileDialog diag = new OpenFileDialog();

            diag.Filter = "Aircraft DB File (*.adb)|*.adb";

            if (diag.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    IList<Aircraft> aircrafts = new List<Aircraft>();

                    using (StreamReader sr = new StreamReader(diag.FileName))
                    {
                        string line;
                        while ((line = sr.ReadLine()) != null)
                        {
                            string[] data = line.Split(';');

                            aircrafts.Add(new Aircraft(data[0], data[1],
                                Color.FromName(data[2])));
                        }
                    }

                    aircraftBox.Items.Clear();
                    aircraftBox.Items.AddRange(aircrafts.ToArray());
                }
                catch (IndexOutOfRangeException ex)
                {
                    MessageBox.Show("Syntax error in input file.", "Error",
                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        #endregion
    }
}
